@@ -1,9 +1,10 @@
 # Ellipses (J. Fox and G. Monette)
 
+# last modified 2 April 02 by J. Fox
 
-ellipse<-function(center, shape, radius, center.pch=19, center.cex=1.5, segments=51, add=T, 
-        xlab="", ylab="", las=1, col=palette()[2], lwd=2, lty=1, ...) {
-    # last modified 25 Feb 2001 by J. Fox
+ellipse<-function(center, shape, radius, center.pch=19, center.cex=1.5, segments=51, add=TRUE, 
+        xlab="", ylab="", las=par("las"), col=palette()[2], lwd=2, lty=1, ...) {
+    # last modified 20 Feb 2002 by J. Fox
     if (! (is.vector(center) && 2==length(center))) stop("center must be a vector of length 2")
     if (! (is.matrix(shape) && all(2==dim(shape)))) stop("shape must be a 2 by 2 matrix")
     angles <- (0:segments)*2*pi/segments 
@@ -16,10 +17,10 @@ ellipse<-function(center, shape, radius, center.pch=19, center.cex=1.5, segments
 }
 
 data.ellipse<-function(x, y, levels=c(0.5, 0.9), center.pch=19, center.cex=1.5,
-        plot.points=T, add=!plot.points, segments=51, robust=F,
+        plot.points=TRUE, add=!plot.points, segments=51, robust=FALSE,
         xlab=deparse(substitute(x)), ylab=deparse(substitute(y)), 
-        las=1, col=palette()[2], pch=1, lwd=2, lty=1, ...) {
-    # last modified 25 Feb 2001 by J. Fox
+        las=par("las"), col=palette()[2], pch=1, lwd=2, lty=1, ...) {
+    # last modified 20 Feb 2002 by J. Fox
     if(missing(y)){
         if(is.matrix(x) && ncol(x)==2) {
             if (missing(xlab)) xlab<-colnames(x)[1]
@@ -57,10 +58,10 @@ confidence.ellipse<-function (model, ...) {
     UseMethod("confidence.ellipse")
     }
     
-confidence.ellipse.lm<-function(model, which.coef, levels=0.95, Scheffe=F, 
+confidence.ellipse.lm<-function(model, which.coef, levels=0.95, Scheffe=FALSE, 
         center.pch=19, center.cex=1.5, segments=51, xlab, ylab, 
-        las=1, col=palette()[2], lwd=2, lty=1, ...){
-    # last modified 16 Feb 2001 by J. Fox
+        las=par("las"), col=palette()[2], lwd=2, lty=1, ...){
+    # last modified 20 Feb 2002 by J. Fox
     which.coef<-if(length(coefficients(model)) == 2) c(1,2)
                 else{
                     if (missing(which.coef)){
@@ -83,10 +84,10 @@ confidence.ellipse.lm<-function(model, which.coef, levels=0.95, Scheffe=F,
     }
 
 
-confidence.ellipse.glm<-function(model, which.coef, levels=0.95, Scheffe=F, 
+confidence.ellipse.glm<-function(model, which.coef, levels=0.95, Scheffe=FALSE, 
         center.pch=19, center.cex=1.5, segments=51, xlab, ylab,
-        las=1, col=palette()[2], lwd=2, lty=1, ...){
-    # last modified 16 Feb 2001 by J. Fox
+        las=par("las"), col=palette()[2], lwd=2, lty=1, ...){
+    # last modified 20 Feb 2002 by J. Fox
     which.coef<-if(length(coefficients(model)) == 2) c(1,2)
                 else{
                     if (missing(which.coef)){
